Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(390)

Unified Diff: chrome/installer/util/util_constants.h

Issue 833513002: Revert of replace COMPILE_ASSERT with static_assert in chrome/installer/ (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/installer/util/shell_util.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/installer/util/util_constants.h
diff --git a/chrome/installer/util/util_constants.h b/chrome/installer/util/util_constants.h
index 530c4f507c90c2ec018411c2cc12b78a66985e32..301f26f889cdb7c46cf00755d973ab989fb064da 100644
--- a/chrome/installer/util/util_constants.h
+++ b/chrome/installer/util/util_constants.h
@@ -95,13 +95,13 @@
UNPACKING_FAILED, // 57. Unpacking the (possibly patched)
// uncompressed archive failed.
// Friendly reminder: note the static_assert below.
};
// Existing InstallStatus values must not change. Always add to the end.
-static_assert(installer::UNPACKING_FAILED == 57,
- "dont change enum");
+COMPILE_ASSERT(installer::UNPACKING_FAILED == 57,
+ dont_change_enum);
// The type of an update archive.
enum ArchiveType {
@@ -141,8 +141,8 @@
// When we start reporting the numerical values from the enum, the order
// above MUST be preserved.
-static_assert(UNINSTALLING_CHROME_FRAME == 20,
- "never ever ever change InstallerStage values!");
+COMPILE_ASSERT(UNINSTALLING_CHROME_FRAME == 20,
+ never_ever_ever_change_InstallerStage_values_bang);
namespace switches {
« no previous file with comments | « chrome/installer/util/shell_util.cc ('k') | no next file » | no next file with comments »
@@ -95,13 +95,13 @@
UNPACKING_FAILED, // 57. Unpacking the (possibly patched)
// uncompressed archive failed.
- // Friendly reminder: note the static_assert below.
+ // Friendly reminder: note the COMPILE_ASSERT below.
};
// Existing InstallStatus values must not change. Always add to the end.

Powered by Google App Engine
This is Rietveld 408576698